@@ -23,6 +23,16 @@ var pathOperatorScenarios = []expressionScenario{
 			"D0, P[a b], (!!seq)::- a\n- b\n",
 		},
 	},
+	{
+		description: "Map path",
+		document:    `{a: {b: cat}}`,
+		skipDoc:     true,
+		expression:  `.a.b | path[]`,
+		expected: []string{
+			"D0, P[a b 0], (!!str)::a\n",
+			"D0, P[a b 1], (!!str)::b\n",
+		},
+	},
 	{
 		skipDoc: true,
 		document: `a:
@@ -129,6 +139,15 @@ var pathOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::a: [frog]\n",
 		},
 	},
+	{
+		description: "Delete splat",
+		skipDoc:     true,
+		document:    `a: [cat, frog]`,
+		expression:  `delpaths([["a", 0]])[]`,
+		expected: []string{
+			"D0, P[a], (!!seq)::[frog]\n",
+		},
+	},
 	{
 		description:    "Delete - wrong parameter",
 		subdescription: "delpaths does not work with a single path array",
