@@ -55,6 +55,24 @@ var sliceArrayScenarios = []expressionScenario{
 			"D0, P[1], (!!seq)::- banana\n- grape\n",
 		},
 	},
+	{
+		skipDoc:     true,
+		description: "second index beyond array clamps",
+		document:    `[cat]`,
+		expression:  `.[:3]`,
+		expected: []string{
+			"D0, P[], (!!seq)::- cat\n",
+		},
+	},
+	{
+		skipDoc:     true,
+		description: "first index beyond array returns nothing",
+		document:    `[cat]`,
+		expression:  `.[3:]`,
+		expected: []string{
+			"D0, P[], (!!seq)::[]\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `[[cat, dog, frog, cow], [apple, banana, grape, mango]]`,
