@@ -230,12 +230,16 @@ name = "Tom"  # name comment
 
 // Reproduce bug for https://github.com/mikefarah/yq/issues/2588
 // Bug: standalone comments inside a table cause subsequent key-values to be assigned at root.
-var issue2588RustToolchainWithComments = `
-[owner]
+var issue2588RustToolchainWithComments = `[owner]
 # comment
 name = "Tomer"
 `
 
+var tableWithComment = `[owner]
+# comment
+[things]
+`
+
 var sampleFromWeb = `# This is a TOML document
 title = "TOML Example"
 
@@ -267,6 +271,16 @@ var subArrays = `
 [[array.subarray.subsubarray]]
 `
 
+var tomlTableWithComments = `[section]
+the_array = [
+  # comment
+  "value 1",
+
+  # comment
+  "value 2",
+]
+`
+
 var expectedSubArrays = `array:
   - subarray:
       - subsubarray:
@@ -574,6 +588,19 @@ var tomlScenarios = []formatScenario{
 		expected:     "null\n",
 		scenarioType: "decode",
 	},
+	{
+		skipDoc:      true,
+		input:        issue2588RustToolchainWithComments,
+		expected:     issue2588RustToolchainWithComments,
+		scenarioType: "roundtrip",
+	},
+	{
+		skipDoc:      true,
+		input:        tableWithComment,
+		expression:   ".owner | headComment",
+		expected:     "comment\n",
+		scenarioType: "roundtrip",
+	},
 	{
 		description:  "Roundtrip: sample from web",
 		input:        sampleFromWeb,
@@ -581,6 +608,12 @@ var tomlScenarios = []formatScenario{
 		expected:     sampleFromWeb,
 		scenarioType: "roundtrip",
 	},
+	{
+		skipDoc:      true,
+		input:        tomlTableWithComments,
+		expected:     tomlTableWithComments,
+		scenarioType: "roundtrip",
+	},
 }
 
 func testTomlScenario(t *testing.T, s formatScenario) {
@@ -933,3 +966,32 @@ func TestTomlStringEscapeColourization(t *testing.T) {
 		})
 	}
 }
+
+func TestTomlEncoderPrintDocumentSeparator(t *testing.T) {
+	encoder := NewTomlEncoder()
+	var buf bytes.Buffer
+	writer := bufio.NewWriter(&buf)
+
+	err := encoder.PrintDocumentSeparator(writer)
+	writer.Flush()
+
+	test.AssertResult(t, nil, err)
+	test.AssertResult(t, "", buf.String())
+}
+
+func TestTomlEncoderPrintLeadingContent(t *testing.T) {
+	encoder := NewTomlEncoder()
+	var buf bytes.Buffer
+	writer := bufio.NewWriter(&buf)
+
+	err := encoder.PrintLeadingContent(writer, "some content")
+	writer.Flush()
+
+	test.AssertResult(t, nil, err)
+	test.AssertResult(t, "", buf.String())
+}
+
+func TestTomlEncoderCanHandleAliases(t *testing.T) {
+	encoder := NewTomlEncoder()
+	test.AssertResult(t, false, encoder.CanHandleAliases())
+}
